@@ -1,19 +1,21 @@
 # -*- coding: utf-8 -*-
 """The main Process module"""
 import abc
+import asyncio
 import contextlib
+import copy
 import enum
 import functools
-import copy
 import logging
-import time
+import re
 import sys
-import uuid
-import asyncio
+import time
 from types import TracebackType
 from typing import (
     Any, Awaitable, Callable, cast, Dict, Generator, Hashable, List, Optional, Sequence, Tuple, Type, Union
 )
+import uuid
+import warnings
 
 try:
     from aiocontextvars import ContextVar
@@ -299,9 +301,9 @@ class Process(StateMachine, persistence.Savable, metaclass=ProcessStateMachineMe
                 self.logger.exception('Process<%s>: failed to register as an RPC subscriber', self.pid)
 
             try:
-                identifier = self._communicator.add_broadcast_subscriber(
-                    self.broadcast_receive, identifier=str(self.pid)
-                )
+                # filter out state change broadcasts
+                subscriber = kiwipy.BroadcastFilter(self.broadcast_receive, subject=re.compile(r'^(?!state_changed).*'))
+                identifier = self._communicator.add_broadcast_subscriber(subscriber, identifier=str(self.pid))
                 self.add_cleanup(functools.partial(self._communicator.remove_broadcast_subscriber, identifier))
             except kiwipy.TimeoutError:
                 self.logger.exception('Process<%s>: failed to register as a broadcast subscriber', self.pid)
@@ -481,9 +483,12 @@ class Process(StateMachine, persistence.Savable, metaclass=ProcessStateMachineMe
         return None
 
     def done(self) -> bool:
+        """Return True if the call was successfully killed or finished running.
+
+        .. deprecated:: 0.18.6
+            Use the `has_terminated` method instead
         """
-        Return True if the call was successfully killed or finished running.
-        """
+        warnings.warn('method is deprecated, use `has_terminated` instead', DeprecationWarning)  # pylint: disable=no-member
         return self._state.is_terminal()
 
     # endregion
@@ -1193,6 +1198,12 @@ class Process(StateMachine, persistence.Savable, metaclass=ProcessStateMachineMe
 
             except KeyboardInterrupt:  # pylint: disable=try-except-raise
                 raise
+            except asyncio.CancelledError:  # pylint: disable=try-except-raise
+                # note this re-raise is only required in python<=3.7,
+                # where asyncio.CancelledError == concurrent.futures.CancelledError
+                # it is encountered when the run_task is cancelled
+                # for python>=3.8 asyncio.CancelledError does not inherit from Exception, so will not be caught below
+                raise
             except Exception:  # pylint: disable=broad-except
                 # Overwrite the next state to go to excepted directly
                 next_state = self.create_state(process_states.ProcessState.EXCEPTED, *sys.exc_info()[1:])
